==> sysidentpy-0.3.4.tar.gz: sysidentpy-0.3.4/docs/landing-page/sponsor.md <==
---
template: overrides/main.html
title: Sponsors
---

# Sponsors

As a free and open source project, SysIdentPy relies on the support of the community for its development. If you work for an organization that uses and benefits from SysIdentPy, please consider supporting us.


SysIdentPy __does not__ follow the __sponsorware__ release strategy, which means
that all features are released to the public at the same time. SysIdentPy is a community driven project, however sponsorships will help to assure its sustainability.


The main goal of sponsorships it to make this project sustainable. Your donation goes to support a variety of services and development as they buy the maintainers of this project time to work on the development of new features, bug fixing, stability improvement, issue triage and general support.


Read on to learn [how to become a sponsor]!

  [how to become a sponsor]: #how-to-become-a-sponsor

## Sponsorships

!!! info "Every donation counts and would be greatly appreciated!"

Sponsorships start as low as [__$1 a month__][how to become a sponsor].[^2]

  [^2]:
    Note that $1 a month is the minimum amount to become a sponsor in Github Sponsor Program.


## How to become a sponsor

Thanks for your interest in sponsoring! In order to become an eligible sponsor
with your GitHub account, visit [wilsonrljr's sponsor profile], and complete
a sponsorship of __$1 a month or more__. You can use your individual or
organization GitHub account for sponsoring.

[:octicons-heart-fill-24:{ .mdx-heart } &nbsp; Join our <span class="mdx-sponsorship-count" data-mdx-component="sponsorship-count"></span> awesome sponsors][wilsonrljr's sponsor profile]{ .md-button .md-button--primary .mdx-sponsorship-button }

<hr />
**Special thanks** to our **sponsors**:

!!! success ":medal: Gold Sponsors"

    <a href="https://github.com/ml-technium">
        <img alt="Technium" src="https://avatars.githubusercontent.com/u/83768197?v=4" width="90" height="90">
    </a>

!!! success ":octicons-person-fill-16: Individual Sponsors"

    <a href="https://github.com/nataliakeles">
        <img alt="Nath Keles" src="https://avatars.githubusercontent.com/u/61664158?v=4" width="90" height="90">
    </a>

<hr />

  [wilsonrljr's sponsor profile]: https://github.com/sponsors/wilsonrljr


### Goals

The following section lists all funding goals. Each goal contains a list of
features prefixed with a checkmark symbol, denoting whether a feature is
:octicons-check-circle-fill-24:{ style="color: #00e676" } already available or
:octicons-check-circle-fill-24:{ style="color: var(--md-default-fg-color--lightest)" } planned, but not yet implemented. When the funding goal is hit, the features
are released for general availability.


## Frequently asked questions

??? question "I don't want to sponsor anymore. Can I cancel my sponsorship?"

    Yes, you can cancel your sponsorship anytime! If you no longer want to sponsor SysIdentPy in GitHub Sponsors, you can request a cancellation which will become effective at the end of the billing cycle. Just remember: sponsorships are non-refundable!

    If you have any problems or further questions, please reach out to
    wilsonrljr@outlook.com.

??? question "We don't want to pay for sponsorship every month. Are there any other options?"

    Yes. You can sponsor on a yearly basis by [switching your GitHub account to a
    yearly billing cycle][billing cycle] or just choose an one time donation.

    If you have any problems or further questions, please reach out to
    wilsonrljr@outlook.com.

      [billing cycle]: https://docs.github.com/en/github/setting-up-and-managing-billing-and-payments-on-github/changing-the-duration-of-your-billing-cycle

==> sysidentpy-0.5.2.tar.gz: sysidentpy-0.5.2/docs/landing-page/sponsor.md <==
---
template: overrides/main.html
title: Sponsors
---

# Sponsors

As a free and open source project, SysIdentPy relies on the support of the community for its development. If you work for an organization that uses and benefits from SysIdentPy, please consider supporting us.


SysIdentPy __does not__ follow the __sponsorware__ release strategy, which means
that all features are released to the public at the same time. SysIdentPy is a community driven project, however sponsorships will help to assure its sustainability.


The main goal of sponsorships it to make this project sustainable. Your donation goes to support a variety of services and development as they buy the maintainers of this project time to work on the development of new features, bug fixing, stability improvement, issue triage and general support.


Read on to learn [how to become a sponsor]!

  [how to become a sponsor]: #how-to-become-a-sponsor

## Sponsorships

!!! info "Every donation counts and would be greatly appreciated!"

Sponsorships start as low as [__$1 a month__][how to become a sponsor].[^2]

  [^2]:
    Note that $1 a month is the minimum amount to become a sponsor in Github Sponsor Program.


## How to become a sponsor

Thanks for your interest in sponsoring! In order to become an eligible sponsor
with your GitHub account, visit [wilsonrljr's sponsor profile], and complete
a sponsorship of __$1 a month or more__. You can use your individual or
organization GitHub account for sponsoring.

[:octicons-heart-fill-24:{ .mdx-heart } &nbsp; Join our <span class="mdx-sponsorship-count" data-mdx-component="sponsorship-count"></span> awesome sponsors][wilsonrljr's sponsor profile]{ .md-button .md-button--primary .mdx-sponsorship-button }

!!! info "If you're in Brazil, you can support me by making a donation via Pix. Just scan the QR code below."
<a href="https://sysidentpy.org/book/0%20-%20Preface/">
  <img src="https://github.com/wilsonrljr/sysidentpy-data/blob/79638c7985475b5d1ab941912f5a5ae9990d1d4d/docs/images/pix_qr_code.jpg?raw=true" alt="Nonlinear System Identification" style="width: 200px; height: auto;" />
</a>

<hr />
**Special thanks** to our **sponsors**:

!!! success ":medal: Gold Sponsors"

    <a href="https://github.com/ml-technium">
        <img alt="Technium" src="https://avatars.githubusercontent.com/u/83768197?v=4" width="90" height="90">
    </a>

!!! success ":star: Monthly Sponsors"

    <a href="https://github.com/statisticallyinsifnificant">
        <img alt="statisticallyinsifnificant" src="https://avatars.githubusercontent.com/u/158107107?v=4" width="90" height="90">
    </a>

!!! success ":gift_heart: Individual Sponsors"

    <a href="https://github.com/nataliakeles">
        <img alt="Nath Keles" src="https://avatars.githubusercontent.com/u/61664158?v=4" width="90" height="90">
    </a>

<hr />

  [wilsonrljr's sponsor profile]: https://github.com/sponsors/wilsonrljr


### Goals

The following section lists all funding goals. Each goal contains a list of
features prefixed with a checkmark symbol, denoting whether a feature is
:octicons-check-circle-fill-24:{ style="color: #00e676" } already available or
:octicons-check-circle-fill-24:{ style="color: var(--md-default-fg-color--lightest)" } planned, but not yet implemented. When the funding goal is hit, the features
are released for general availability.


## Frequently asked questions

??? question "I don't want to sponsor anymore. Can I cancel my sponsorship?"

    Yes, you can cancel your sponsorship anytime! If you no longer want to sponsor SysIdentPy in GitHub Sponsors, you can request a cancellation which will become effective at the end of the billing cycle. Just remember: sponsorships are non-refundable!

    If you have any problems or further questions, please reach out to
    wilsonrljr@outlook.com.

??? question "We don't want to pay for sponsorship every month. Are there any other options?"

    Yes. You can sponsor on a yearly basis by [switching your GitHub account to a
    yearly billing cycle][billing cycle] or just choose an one time donation.

    If you have any problems or further questions, please reach out to
    wilsonrljr@outlook.com.

      [billing cycle]: https://docs.github.com/en/github/setting-up-and-managing-billing-and-payments-on-github/changing-the-duration-of-your-billing-cycle
